Solution checker
################

Test a known solution in an optimization model using Gurobi Optimizer


.. toctree::
   :maxdepth: 2

   quickstart_solcheck
   howitworks_solcheck
   usage_solcheck
   apiref_solcheck
   tips_solcheck
